# Slot: source_file_date


modification date of the source of the schema

URI: [http://w3id.org/biolink/biolinkml/meta/source_file_date](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -><sub>opt</sub> [Datetime](Datetime.md)
## Inheritance

## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
